Crate mevy_ui_syntax Copy item path Source approx cheaper but inaccurate math implementations buns convert_case Converts to and from various cases. derive_more derive_moreproc_macro2 github crates-io docs-rs quote github crates-io docs-rs random quick and easy randomness syn github crates-io docs-rs default exit flow_base flow_base_let foname hold kill match_fns Alternative Syntax to attach functionality to type variants: next paste qonst create a constant struct and name it after itself qt The whole point. qts Same as quote!, but applies a given span to all tokens originating within
the macro invocation. quimp Quick Implementations: sandwich Create a code template and use it right after: trait_alias tycell xoxo Replace every bool to a X or O: Ghost Zero-sized type used to mark things that “act like” they own a T. Group A delimited token stream. Ident A word of Rust code, which may be a keyword or legal variable name. Lazy A value which is initialized on the first access. Literal A literal string ("hello"), byte string (b"hello"), character ('a'),
byte character (b'a'), an integer or floating point number with or without
a suffix (1, 1u8, 2.3, 2.3f32). OnceCell A thread-safe cell which can be written to only once. Punct A Punct is a single punctuation character like +, - or #. Span A region of source code, along with macro expansion information. StackMap Keys keep the order they’re added in. TokenStream An abstract stream of tokens, or more concretely a sequence of token trees. UiEntry UiPrep UiToken Case Defines the type of casing a string can be. Check Token Level Return Delimiter Describes how a sequence of token trees is delimited. Step Stream Level Return TokenTree A single token or a delimited sequence of token trees (e.g. [1, (), ..]). Casing Describes items that can be converted into a case. This trait is used
in conjunction with the StateConverter struct which is returned from a couple
methods on Casing. Clerpable Cycle mainly meant for: #[derive(Cycle)] on simple enums CycleMath CycleStapable DTreeIterExt This is an extension trait for the following impl: DefaultClear DekiExtApprox This is an extension trait for the following impl: DekiExtF32 This is an extension trait for the following impl: DekiExtVecRng This is an extension trait for the following impl: DekiOptTokenTreeExt This is an extension trait for the following impl: DekiTokenTreeExt This is an extension trait for the following impl: DelimiterExt This is an extension trait for the following impl: Glerpable Any type that implements necessary math traits for linear interpolation (lerp) IdentExt This is an extension trait for the following impl: Identasdf This is an extension trait for the following impl: Lerpable Any type that implemients necessary math traits for linear interpolation (lerp) LerpableF32 Any type that implemients necessary math traits for linear interpolation (lerp) LiteralExt This is an extension trait for the following impl: MulF32 This is an extension trait for the following impl: PunctExt This is an extension trait for the following impl: RangeOffset This is an extension trait for the following impl: Spanned A trait that can provide the Span of the complete contents of a syntax
tree node. Stepable StringProcExt This is an extension trait for the following impl: Syncable ‘Short form’ for: ’static+Send+Sync ToTokens Types that can be interpolated inside a quote! invocation. TokenStreamExt This is an extension trait for the following impl: TreeIterExt This is an extension trait for the following impl: TreeIterExt2 This is an extension trait for the following impl: UiLiteral This is an extension trait for the following impl: UiPeekIter This is an extension trait for the following impl: UiTokenTree This is an extension trait for the following impl: UiVec This is an extension trait for the following impl: YayNay bundle bundle_slim code simple in-code replacement of: imp Quickly add a method to a Type quick_cycle_add quick_cycle_sub ui_style_sheet PeekIter Str deref derive(..) preset for:
drv::Deref,drv::DerefMut ext hashable derive(..) preset for:
PartialEq,Eq,Hash,Clone,Copy imp Quickly add a method to a Type serde derive(..) preset for:
Serialize,Deserialize,Clone serde_hash derive(..) preset for:
Serialize,Deserialize,PartialEq,Eq,Hash,Clone,Copy Constructor Cycle ForceDefault